@@ -26,7 +26,7 @@ class PaymentIntentClient(HttpClient):
         You should use this API to get the complete, up-to-date information
         about a Payment Intent.
         """
-        return PaymentIntent(self.do_get("{}/{}".format(self._url, id_))["data"])
+        return PaymentIntent.from_json(self.do_get(f"{self._url}/{id_}")["data"])
 
     def confirm(self, id_):
         """Confirm a Payment Intent
@@ -38,8 +38,8 @@ class PaymentIntentClient(HttpClient):
         Once confirmed, the amount charged to your customer's card will be added
         to your Balance (minus any Duffel Payment fees).
         """
-        url = "{}/{}/actions/confirm".format(self._url, id_)
-        return PaymentIntent(self.do_post(url)["data"])
+        url = f"{self._url}/{id_}/actions/confirm"
+        return PaymentIntent.from_json(self.do_post(url)["data"])
 
 
 class PaymentIntentCreate:
@@ -85,4 +85,4 @@ class PaymentIntentCreate:
                 }
             },
         )
-        return PaymentIntent(res["data"])
+        return PaymentIntent.from_json(res["data"])
