@@ -28,7 +28,7 @@ class WebhookClient(HttpClient):
 
         Send a ping, a "fake event" notification, to a webhook.
         """
-        url = "{}/{}/actions/ping".format(self._url, id_)
+        url = f"{self._url}/{id_}/actions/ping"
         self.do_post(url)
         return None
 
@@ -55,7 +55,7 @@ class WebhookCreate(object):
             self._client._url,
             body={"data": {"events": self._events, "url": self._url}},
         )
-        return Webhook(res["data"])
+        return Webhook.from_json(res["data"])
 
 
 class WebhookUpdate(object):
@@ -72,11 +72,11 @@ class WebhookUpdate(object):
 
     def execute(self):
         """PATCH /air/webhooks/{id}"""
-        url = "{}/{}".format(self._client._url, self._id)
+        url = f"{self._client._url}/{self._id}"
 
         res = self._client.do_patch(
             url,
             body={"data": {"active": self._active}},
         )
 
-        return Webhook(res["data"])
+        return Webhook.from_json(res["data"])
